AIRepository class
@Author: zhuweiyi @Description: 描述 @CreateDate: 2025/11/6 10:26
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createAITask(
) → Future -
deleteAITask(
int taskId) → Future -
deleteAllAITask(
) → Future -
editAITask(
int resultId, String input) → Future< AiStateModel> -
finishAITask(
) → Future -
getAIFileById(
int id) → Future -
getAIFileUrlPrefix(
) → Future -
getAIPresetImgs(
) → Future< List< String> > -
getAIPresetTips(
) → Future -
getAITaskList(
) → Future -
getAITaskResult(
int historyTaskId) → Future< AiStateModel> -
getCurrentTaskState(
) → Future< AiStateModel> -
interruptAITask(
) → Future -
markAITaskResultDownloaded(
int resultId) → dynamic -
queryAITaskStatus(
) → Future< AiStateModel> -
startAITask(
String input) → Future< AiStateModel>