AiImage class
@Author: zhuweiyi @Description: 描述 @CreateDate: 2025/9/24 17:40
Constructors
- AiImage()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- aiBackImage ↔ Image
-
getter/setter pair
- aiCreateImage ↔ Image
-
getter/setter pair
- aiDelImage ↔ Image
-
getter/setter pair
- aiDownloadImage ↔ Image
-
getter/setter pair
- aiFlammaBackImage ↔ Image
-
getter/setter pair
- aiFlammaCreateImage ↔ Image
-
getter/setter pair
- aiFlammaDownloadImage ↔ Image
-
getter/setter pair
- aiFlammaHistoryImage ↔ Image
-
getter/setter pair
- aiHistoryImage ↔ Image
-
getter/setter pair
- aiPauseImage ↔ Image
-
getter/setter pair
- aiPlayImage ↔ Image
-
getter/setter pair
Static Methods
-
aiFlammaSendImage(
Color color) → Image -
aiSendImage(
Color color) → Image
Constants
- aiBackString → const String
- aiCreateString → const String
- aiDeleteString → const String
- aiDownloadString → const String
- aiHistoryString → const String
- aiPauseString → const String
- aiPlayString → const String
- aiSendString → const String