AiStateModel class
task_id : 22
user_id : 999
device_type : "f15i"
original_input : "挪威的森林"
status : "running"
fail_reason : null
created_at : "2025-11-06 10:57:05"
updated_at : "2025-11-06 10:58:11"
current_stage : {"stage_id":12,"stage_number":1,"status":"completed","created_at":"2025-11-06 10:57:38","completed_at":"2025-11-06 10:58:11","results":{"result_id":31,"result_index":3,"preset_name":"norwegian_forest_3","file_url":"/output/f15i/20251106/22_105810_3.preset","status":"file_saved","error_message":null,"is_downloaded":false,"created_at":"2025-11-06 10:58:11"}}
all_stages : [{"stage_id":12,"stage_number":1,"status":"completed","created_at":"2025-11-06 10:57:38","completed_at":"2025-11-06 10:58:11","results":{"result_id":29,"result_index":1,"preset_name":"norwegian_forest_1","file_url":"/output/f15i/20251106/22_105755_1.preset","status":"file_saved","error_message":null,"is_downloaded":false,"created_at":"2025-11-06 10:57:55"},{"result_id":30,"result_index":2,"preset_name":"norwegian_forest_2","file_url":"/output/f15i/20251106/22_105802_2.preset","status":"file_saved","error_message":null,"is_downloaded":false,"created_at":"2025-11-06 10:58:03"},{"result_id":31,"result_index":3,"preset_name":"norwegian_forest_3","file_url":"/output/f15i/20251106/22_105810_3.preset","status":"file_saved","error_message":null,"is_downloaded":false,"created_at":"2025-11-06 10:58:11"}}]
Constructors
-
AiStateModel({num? taskId, num? userId, String? deviceType, String? originalInput, String? status, dynamic failReason, String? createdAt, String? updatedAt, CurrentStage? currentStage, List<
AllStages> ? allStages}) - AiStateModel.fromJson(dynamic json)
Properties
-
allStages
↔ List<
AllStages> ? -
getter/setter pair
- createdAt ↔ String?
-
getter/setter pair
- currentStage ↔ CurrentStage?
-
getter/setter pair
- deviceType ↔ String?
-
getter/setter pair
- failReason ↔ dynamic
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- originalInput ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
getter/setter pair
- taskId ↔ num?
-
getter/setter pair
- updatedAt ↔ String?
-
getter/setter pair
- userId ↔ num?
-
getter/setter pair
Methods
-
copyWith(
{num? taskId, num? userId, String? deviceType, String? originalInput, String? status, dynamic failReason, String? createdAt, String? updatedAt, CurrentStage? currentStage, List< AllStages> ? allStages}) → AiStateModel -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited