Results class
result_id : 29 result_index : 1 preset_name : "norwegian_forest_1" file_url : "/output/f15i/20251106/22_105755_1.preset" status : "file_saved" error_message : null is_downloaded : false created_at : "2025-11-06 10:57:55"
Constructors
Properties
- createdAt ↔ String?
-
getter/setter pair
- errorMessage ↔ dynamic
-
getter/setter pair
- fileUrl ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDownloaded ↔ bool?
-
getter/setter pair
- presetName ↔ String?
-
getter/setter pair
- resultId ↔ num?
-
getter/setter pair
- resultIndex ↔ num?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
getter/setter pair
Methods
-
copyWith(
{num? resultId, num? resultIndex, String? presetName, String? fileUrl, String? status, dynamic errorMessage, bool? isDownloaded, String? createdAt}) → Results -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited